==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/StringMatchExactFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StringMatchExactFluent<A extends StringMatchExactFluent<A>> extends BaseFluent<A>{
  public StringMatchExactFluent() {
  }
  public StringMatchExactFluent(StringMatchExact instance) {
    instance = (instance != null ? instance : new StringMatchExact());

    if (instance != null) {
      this.withExact(instance.getExact());
      this.withExact(instance.getExact());
    }
  }
  private String exact;
  public String getExact() {
    return this.exact;
  }
  public A withExact(String exact) {
    this.exact=exact; return (A) this;
  }
  public boolean hasExact() {
    return this.exact != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringMatchExactFluent that = (StringMatchExactFluent) o;
    if (!java.util.Objects.equals(exact, that.exact)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(exact,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exact != null) { sb.append("exact:"); sb.append(exact); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/StringMatchExactFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StringMatchExactFluent<A extends StringMatchExactFluent<A>> extends BaseFluent<A>{
  public StringMatchExactFluent() {
  }
  
  public StringMatchExactFluent(StringMatchExact instance) {
    this.copyInstance(instance);
  }
  private String exact;
  
  protected void copyInstance(StringMatchExact instance) {
    instance = (instance != null ? instance : new StringMatchExact());
  
    if (instance != null) {
        this.withExact(instance.getExact());
        this.withExact(instance.getExact());
      }
  }
  
  public String getExact() {
    return this.exact;
  }
  
  public A withExact(String exact) {
    this.exact=exact; return (A) this;
  }
  
  public boolean hasExact() {
    return this.exact != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringMatchExactFluent that = (StringMatchExactFluent) o;
    if (!java.util.Objects.equals(exact, that.exact)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(exact,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exact != null) { sb.append("exact:"); sb.append(exact); }
    sb.append("}");
    return sb.toString();
  }
  

}
